#' Example \code{RasterStack} object
#'
#' A set of two conceptually different types of raster.
#'
#' @format The object of class RasterStack has no projection and is a
#'   RasterStack object of 56 by 60 cells. The first raster represents
#'   land-use classes and the second raster contains a continuous scale of
#'   vegetation cover.
"gtRasters"

#' Example \code{geom} objects
#'
#' A set of five geometries.
#' @format The list contains five objects of class geom, a \code{point},
#'   \code{line} and \code{polygon} object and two \code{grid} geoms, one with
#'   categorical data and one with continuous data. They are mostly used in the
#'   example and test-sections of this package.
"gtGeoms"

#' Example \code{Spatial} objects
#'
#' A set of four sp objects
#' @format The list contains four objects of class \code{Spatial}, a
#'   \code{SpatialPoints}, a \code{SpatialMultiPoints}, a, \code{SpatialLines}
#'   and a \code{SpatialPolygons} object. They are mostly used in the example
#'   and test-sections of this package.
"gtSP"

#' Example \code{sf} objects
#'
#' A set of six sp objects
#' @format The list contains six objects of class \code{sf}, a \code{POINT}, a
#'   \code{MULTIPOINT}, a \code{LINESTRING}, a \code{MULTILINESTRING}, a
#'   \code{POLYGON}, and a \code{MULTIPOLYGON} object. They are mostly used in
#'   the example and test-sections of this package.
"gtSF"

#' Default visualising theme
#'
"gtTheme"

#' Clocaenog 6 sample data
#'
#' Sample data of tree species and their position that have been sampled by Arne
#' Pommerening, 2012 (https://www.pommerening.org).
#'
#' The list contains two items, first the tree specific data, seconda look-up
#' table of the species names.
"clocaenog"